**********************
Project CARS Race Data
**********************

 .. image:: https://travis-ci.org/SenorPez/project-cars-race-data.svg?branch=0.1-devel
    :target: https://travis-ci.org/SenorPez/project-cars-race-data

.. image:: https://codecov.io/gh/SenorPez/project-cars-race-data/branch/0.1-devel/graph/badge.svg
  :target: https://codecov.io/gh/SenorPez/project-cars-race-data

Processes Project CARS Telemetry Data to create data about races.

Current release: 0.1  
Current edge state: Rough  
Current mood: Hopeful

The Project CARS Race Data (PCRD) is a Python package intended to process Project CARS Telemetry Data and make that data available for further use.

Requirements
============
- `Python 3.3 <https://www.python.org/download/releases/3.3.0/>`_ or greater

Installation
============
The Project CARS Race Data can be installed with ``pip``: ``pip install racedata``.

Usage
=====
The Project CARS Race Data is a python package, and can be imported into your project:  
``from racedata import RaceData``
